@@ -54,28 +54,25 @@ gsm_client_list_class_init (GsmClientListClass *klass)
   gsm_client_list_signals[DIRTY] =
     gtk_signal_new ("dirty",
 		    GTK_RUN_LAST,
-		    object_class->type,
+		    GTK_CLASS_TYPE (object_class),
 		    GTK_SIGNAL_OFFSET (GsmClientListClass, dirty),
 		    gtk_signal_default_marshaller,
 		    GTK_TYPE_NONE, 0); 
   gsm_client_list_signals[STARTED] =
     gtk_signal_new ("started",
 		    GTK_RUN_LAST,
-		    object_class->type,
+		    GTK_CLASS_TYPE (object_class),
 		    GTK_SIGNAL_OFFSET (GsmClientListClass, started),
 		    gtk_signal_default_marshaller,
 		    GTK_TYPE_NONE, 0); 
   gsm_client_list_signals[INITIALIZED] =
     gtk_signal_new ("initialized",
 		    GTK_RUN_LAST,
-		    object_class->type,
+		    GTK_CLASS_TYPE (object_class),
 		    GTK_SIGNAL_OFFSET (GsmClientListClass, initialized),
 		    gtk_signal_default_marshaller,
 		    GTK_TYPE_NONE, 0); 
 
-  gtk_object_class_add_signals (object_class, gsm_client_list_signals, 
-				NSIGNALS);
-
   klass->dirty       = dirty;
   klass->started     = NULL;
   klass->initialized = NULL;
@@ -108,21 +105,22 @@ gsm_client_list_get_type (void)
 GtkWidget* 
 gsm_client_list_new (void)
 {
-  GsmClientList* client_list = gtk_type_new(gsm_client_list_get_type());
-  GtkCList* clist = (GtkCList*) client_list;
+  GsmClientList* client_list;
+  GtkCList* clist;
   GdkFont*  font;
-  gchar*    titles[4];  
-  int i;
+  int i, n_titles;
+  gchar*    titles[4] = { N_("Order"), N_("Style"), N_("State"), N_("Program") };
 
-/* Changes to build on IRIX */
-  
-  titles[0] = N_("Order"); 
-  titles[1] = N_("Style"); 
-  titles[2] = N_("State");
-  titles[3] = N_("Program");
+  n_titles = sizeof (titles) / sizeof (titles[0]);
 
-  for(i = 0; i < sizeof(titles)/sizeof(titles[0]); i++)
-    titles[i] = gettext(titles[i]);
+  client_list = g_object_new (gsm_client_list_get_type(),
+			      "n_columns", n_titles,
+			      NULL);
+  clist = GTK_CLIST (client_list);
+
+  for (i = 0; i < n_titles; i++)
+	  gtk_clist_set_column_title (clist, i, _(titles[i]));
+  gtk_clist_column_titles_show (clist);
 
   client_list->client_editor = gsm_client_editor_new ();
   client_list->session   = NULL;
@@ -130,7 +128,6 @@ gsm_client_list_new (void)
   client_list->dirty     = FALSE;
   client_list->changes   = NULL;
 
-  gtk_clist_construct (clist, 4, titles);
   gtk_signal_connect(GTK_OBJECT(client_list), "select_row",
 		     GTK_SIGNAL_FUNC (select_cb), NULL);
   gtk_signal_connect(GTK_OBJECT(client_list), "unselect_row",
@@ -146,9 +143,11 @@ gsm_client_list_new (void)
   gtk_clist_set_column_justification (clist, 2, GTK_JUSTIFY_CENTER);
   gtk_clist_column_titles_passive (clist);
 
+#if 0
   font = gtk_widget_get_style (GTK_WIDGET (client_list))->font;
   gtk_clist_set_column_min_width (clist, 3, 40 * gdk_string_width (font, "n"));
   gtk_clist_set_column_max_width (clist, 3, 50 * gdk_string_width (font, "n"));
+#endif
   return GTK_WIDGET (client_list);
 }
 
@@ -413,31 +412,21 @@ gsm_client_list_add_program (GsmClientList* client_list, gchar* command)
 void
 gsm_client_list_remove_selection (GsmClientList* client_list)
 {
-  GtkCList* clist = NULL;
-  gint row = 0;
- 
+  GtkCList* clist = (GtkCList*)client_list;
+
   g_return_if_fail(client_list != NULL);
   g_return_if_fail(GSM_IS_CLIENT_LIST(client_list));
-  
-  clist = (GtkCList*)client_list;
-  
-  if (!clist->selection)
-    return;
-  
-  row = GPOINTER_TO_INT (clist->selection->data);
 
   gtk_clist_freeze (clist);
   {
+    gint row = GPOINTER_TO_INT (clist->selection->data);
     gpointer data = gtk_clist_get_row_data (clist, row);
     GsmClientRow* client_row = GSM_CLIENT_ROW (data);
     
-    if (client_row) {
-      gsm_client_row_remove (client_row);
-      register_change (client_list, client_row, GSM_CLIENT_ROW_REMOVE);
-    }
+    gsm_client_row_remove (client_row);
+    register_change (client_list, client_row, GSM_CLIENT_ROW_REMOVE);
   }
   gtk_clist_thaw (clist);
-  gtk_clist_select_row (clist, row - 1, 0);
 }
 
 static void
