@@ -1,7 +1,8 @@
 #include <config.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <gnome.h>
+#include <libgnome/gnome-i18n.h>
+#include <libgnome/gnome-util.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libart_lgpl/art_misc.h>
 #include <libart_lgpl/art_affine.h>
@@ -14,10 +15,14 @@
 #include "panel_config_global.h"
 #include "rgb-stuff.h"
 
+#undef BUTTON_WIDGET_DEBUG
+
+#define BUTTON_WIDGET_DISPLACEMENT 5
+
 extern GlobalConfig global_config;
 
 static void button_widget_class_init	(ButtonWidgetClass *klass);
-static void button_widget_init		(ButtonWidget      *button);
+static void button_widget_instance_init	(ButtonWidget      *button);
 static void button_widget_size_request  (GtkWidget         *widget,
 					 GtkRequisition    *requisition);
 static void button_widget_size_allocate (GtkWidget         *widget,
@@ -26,8 +31,6 @@ static void button_widget_realize	(GtkWidget         *widget);
 static void button_widget_unrealize     (GtkWidget         *widget);
 static void button_widget_map           (GtkWidget         *widget);
 static void button_widget_unmap         (GtkWidget         *widget);
-static void button_widget_real_draw     (GtkWidget         *widget,
-					 GdkRectangle      *area);
 
 static gboolean  button_widget_button_press	(GtkWidget         *widget,
 						 GdkEventButton    *event);
@@ -43,46 +46,32 @@ static void button_widget_unpressed	(ButtonWidget *button);
 /*list of all the button widgets*/
 static GList *buttons = NULL;
 
-/*the tiles go here*/
-static struct {
-	GdkPixbuf *tiles_up[LAST_TILE];
-	GdkPixbuf *tiles_up_hc[LAST_TILE];
-	GdkPixbuf *tiles_down[LAST_TILE];
-	GdkPixbuf *tiles_down_hc[LAST_TILE];
-} tiles = {{NULL}}; /*ansi C trick to make it all 0*/
+static GtkWidgetClass *button_widget_parent_class;
 
-static int tile_border[LAST_TILE]={0,0,0,0};
-static int tile_depth[LAST_TILE]={0,0,0,0};
-
-/*are tiles enabled*/
-static gboolean tiles_enabled[LAST_TILE] = {FALSE,FALSE,FALSE,FALSE};
-
-static gboolean pixmaps_enabled[LAST_TILE] = {TRUE,TRUE,TRUE,TRUE};
-static gboolean always_text[LAST_TILE] = {FALSE,FALSE,FALSE,FALSE}; /*text always displayed*/
-
-static GtkWidgetClass *parent_class;
-
-guint
+GType
 button_widget_get_type (void)
 {
-	static guint button_widget_type = 0;
+	static GType object_type = 0;
 
-	if (!button_widget_type) {
-		GtkTypeInfo button_widget_info = {
-			"ButtonWidget",
-			sizeof (ButtonWidget),
+	if (object_type == 0) {
+		static const GTypeInfo object_info = {
 			sizeof (ButtonWidgetClass),
-			(GtkClassInitFunc) button_widget_class_init,
-			(GtkObjectInitFunc) button_widget_init,
-			(GtkArgSetFunc) NULL,
-			(GtkArgGetFunc) NULL,
+                    	(GBaseInitFunc)         NULL,
+                    	(GBaseFinalizeFunc)     NULL,
+                    	(GClassInitFunc)        button_widget_class_init,
+                    	NULL,                   /* class_finalize */
+                    	NULL,                   /* class_data */
+                    	sizeof (ButtonWidget),
+                    	0,                      /* n_preallocs */
+                    	(GInstanceInitFunc)     button_widget_instance_init
+
 		};
 
-		button_widget_type = gtk_type_unique (GTK_TYPE_WIDGET,
-						      &button_widget_info);
+		object_type = g_type_register_static (GTK_TYPE_WIDGET, "ButtonWidget", &object_info, 0);
+		button_widget_parent_class = g_type_class_ref (GTK_TYPE_WIDGET);
 	}
 
-	return button_widget_type;
+	return object_type;
 }
 
 enum {
@@ -97,40 +86,42 @@ static guint button_widget_signals[LAST_SIGNAL] = {0};
 static void
 button_widget_class_init (ButtonWidgetClass *class)
 {
-	GtkObjectClass *object_class = (GtkObjectClass*) class;
-	GtkWidgetClass *widget_class = (GtkWidgetClass*) class;
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
-	parent_class = gtk_type_class (GTK_TYPE_WIDGET);
 
 	button_widget_signals[CLICKED_SIGNAL] =
-		gtk_signal_new("clicked",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(ButtonWidgetClass,
-			       			 clicked),
-			       gtk_signal_default_marshaller,
-			       GTK_TYPE_NONE,
-			       0);
+		g_signal_new ("clicked",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (ButtonWidgetClass, clicked),
+                              NULL,
+                              NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
+
 	button_widget_signals[PRESSED_SIGNAL] =
-		gtk_signal_new("pressed",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(ButtonWidgetClass,
-			       			 pressed),
-			       gtk_signal_default_marshaller,
-			       GTK_TYPE_NONE,
-			       0);
+		g_signal_new ("pressed",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (ButtonWidgetClass, pressed),
+                              NULL,
+                              NULL,
+                              g_cclosure_marshal_VOID__VOID,
+                              G_TYPE_NONE,
+                              0);
+
 	button_widget_signals[UNPRESSED_SIGNAL] =
-		gtk_signal_new("unpressed",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(ButtonWidgetClass,
-			       			 unpressed),
-			       gtk_signal_default_marshaller,
-			       GTK_TYPE_NONE,
-			       0);
-	gtk_object_class_add_signals(object_class,button_widget_signals,
-				     LAST_SIGNAL);
+		g_signal_new ("unpressed",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (ButtonWidgetClass, unpressed),
+                              NULL,
+                              NULL,
+                              g_cclosure_marshal_VOID__VOID,
+                              G_TYPE_NONE,
+                              0);
 	
 	class->clicked = NULL;
 	class->pressed = button_widget_pressed;
@@ -138,7 +129,6 @@ button_widget_class_init (ButtonWidgetClass *class)
 
 	widget_class->realize = button_widget_realize;
 	widget_class->unrealize = button_widget_unrealize;
-	widget_class->draw = button_widget_real_draw;
 	widget_class->map = button_widget_map;
 	widget_class->unmap = button_widget_unmap;
 	widget_class->size_allocate = button_widget_size_allocate;
@@ -150,24 +140,15 @@ button_widget_class_init (ButtonWidgetClass *class)
 	
 }
 
+
+ 
 static void
 setup_no_alpha(ButtonWidget *button)
 {
 	button->no_alpha = 0;
-	if(!tiles_enabled[button->tile] ||
-	   global_config.tile_when_over)
-		return;
-	if(button->pressed) {
-		if(tiles.tiles_down[button->tile] &&
-		   !gdk_pixbuf_get_has_alpha(tiles.tiles_down[button->tile]))
-			button->no_alpha = 1;
-	} else {
-		if(tiles.tiles_up[button->tile] &&
-		   !gdk_pixbuf_get_has_alpha(tiles.tiles_up[button->tile]))
-			button->no_alpha = 1;
-	}
 }
 
+
 static void
 translate_to(GtkWidget *from, GtkWidget *to, int *x, int *y)
 {
@@ -206,7 +187,7 @@ calculate_overlay_geometry (PanelWidget *panel, GtkWidget *parent,
 	/* XXX: These window thingies should really be unmapped in hidden
 	 * case, or something like that, this is ugly, but who gives a fuck,
 	 * this is all going to be rewritten soon (famous last words?) */
-	if(IS_BASEP_WIDGET(parent) &&
+	if(BASEP_IS_WIDGET(parent) &&
 	   BASEP_WIDGET(parent)->state != BASEP_SHOWN &&
 	   BASEP_WIDGET(parent)->state != BASEP_AUTO_HIDDEN) {
 		*x = parent->requisition.width + 1;
@@ -231,7 +212,7 @@ calculate_overlay_geometry (PanelWidget *panel, GtkWidget *parent,
 			*w = panel->size - applet->allocation.x;
 		}
 
-		if ( ! IS_BASEP_WIDGET(parent)) {
+		if ( ! BASEP_IS_WIDGET(parent)) {
 			/*don't do the edge flushing on foobar*/
 			return;
 		}
@@ -261,7 +242,7 @@ calculate_overlay_geometry (PanelWidget *panel, GtkWidget *parent,
 			*h = panel->size - applet->allocation.y;
 		}
 
-		if ( ! IS_BASEP_WIDGET(parent)) {
+		if ( ! BASEP_IS_WIDGET(parent)) {
 			/*don't do the edge flushing on foobar*/
 			return;
 		}
@@ -291,7 +272,7 @@ button_widget_realize(GtkWidget *widget)
 	int x,y,w,h;
 
 	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_BUTTON_WIDGET (widget));
+	g_return_if_fail (BUTTON_IS_WIDGET (widget));
 
 	panel = PANEL_WIDGET(widget->parent);
 	parent = panel->panel_parent;
@@ -334,7 +315,7 @@ button_widget_unrealize (GtkWidget *widget)
 	ButtonWidget *button_widget;
   
 	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_BUTTON_WIDGET (widget));
+	g_return_if_fail (BUTTON_IS_WIDGET (widget));
 
 	button_widget = BUTTON_WIDGET (widget);
 	
@@ -342,32 +323,32 @@ button_widget_unrealize (GtkWidget *widget)
 	gdk_window_destroy (button_widget->event_window);
 	button_widget->event_window = NULL;
 	
-	if (GTK_WIDGET_CLASS (parent_class)->unrealize)
-		(* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
+	if (GTK_WIDGET_CLASS (button_widget_parent_class)->unrealize)
+		(* GTK_WIDGET_CLASS (button_widget_parent_class)->unrealize) (widget);
 }
 
 static void
 button_widget_map (GtkWidget *widget)
 {
 	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_BUTTON_WIDGET (widget));
+	g_return_if_fail (BUTTON_IS_WIDGET (widget));
 
 	if (GTK_WIDGET_REALIZED (widget) && !GTK_WIDGET_MAPPED (widget))
 		gdk_window_show (BUTTON_WIDGET (widget)->event_window);
 
-	GTK_WIDGET_CLASS (parent_class)->map (widget);
+	GTK_WIDGET_CLASS (button_widget_parent_class)->map (widget);
 }
 
 static void
 button_widget_unmap (GtkWidget *widget)
 {
 	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_BUTTON_WIDGET (widget));
+	g_return_if_fail (BUTTON_IS_WIDGET (widget));
 
 	if (GTK_WIDGET_MAPPED (widget))
 		gdk_window_hide (BUTTON_WIDGET (widget)->event_window);
 
-	GTK_WIDGET_CLASS (parent_class)->unmap (widget);
+	GTK_WIDGET_CLASS (button_widget_parent_class)->unmap (widget);
 }
 
 static void
@@ -402,21 +383,23 @@ loadup_file(const char *file)
 	if (string_empty (file))
 		return NULL;
 
-	if ( ! g_path_is_absolute(file)) {
+	if (!g_path_is_absolute (file)) {
 		char *f;
-		f = gnome_pixmap_file (file);
-		if (f != NULL) {
-			pb = gdk_pixbuf_new_from_file(f);
+
+		f = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+					       file, TRUE, NULL);
+		if (f) {
+			pb = gdk_pixbuf_new_from_file (f, NULL);
 			g_free (f);
 		}
 	} else {
-		pb = gdk_pixbuf_new_from_file (file);
+		pb = gdk_pixbuf_new_from_file (file, NULL);
 	}
 	return pb;
 }
 
 #if 0
-/*#define INTENSITY(r, g, b) ((r) * 0.30 + (g) * 0.59 + (b) * 0.11)*/
+/* #define INTENSITY(r, g, b) ((r) * 0.30 + (g) * 0.59 + (b) * 0.11) */
 #define INTENSITY(r, g, b) (((r)*77 + (g)*150 + (b)*28)>>8)
 
 /* saturation is 0-255, darken is 0-255 */
@@ -513,10 +496,10 @@ do_colorshift (GdkPixbuf *dest, GdkPixbuf *src, int shift)
 #define SCALE(x) (((x)*size)/48.0)
 
 static void
-draw_arrow(GdkPoint *points, PanelOrientType orient, int size)
+draw_arrow(GdkPoint *points, PanelOrient orient, int size)
 {
 	switch(orient) {
-	case ORIENT_UP:
+	case PANEL_ORIENT_UP:
 		points[0].x = SCALE(48-12);
 		points[0].y = SCALE(10);
 		points[1].x = SCALE(48-4);
@@ -524,7 +507,7 @@ draw_arrow(GdkPoint *points, PanelOrientType orient, int size)
 		points[2].x = SCALE(48-8);
 		points[2].y = SCALE(3);
 		break;
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_DOWN:
 		points[0].x = SCALE(4);
 		points[0].y = SCALE(48 - 10);
 		points[1].x = SCALE(12);
@@ -532,7 +515,7 @@ draw_arrow(GdkPoint *points, PanelOrientType orient, int size)
 		points[2].x = SCALE(8);
 		points[2].y = SCALE(48 - 3);
 		break;
-	case ORIENT_LEFT:
+	case PANEL_ORIENT_LEFT:
 		points[0].x = SCALE(10);
 		points[0].y = SCALE(4);
 		points[1].x = SCALE(10);
@@ -540,7 +523,7 @@ draw_arrow(GdkPoint *points, PanelOrientType orient, int size)
 		points[2].x = SCALE(3);
 		points[2].y = SCALE(8);
 		break;
-	case ORIENT_RIGHT:
+	case PANEL_ORIENT_RIGHT:
 		points[0].x = SCALE(48 - 10);
 		points[0].y = SCALE(48 - 12);
 		points[1].x = SCALE(48 - 10);
@@ -555,7 +538,7 @@ void
 button_widget_set_dnd_highlight(ButtonWidget *button, gboolean highlight)
 {
 	g_return_if_fail (button != NULL);
-	g_return_if_fail (IS_BUTTON_WIDGET (button));
+	g_return_if_fail (BUTTON_IS_WIDGET (button));
 
 	if(button->dnd_highlight != highlight) {
 		button->dnd_highlight = highlight;
@@ -563,198 +546,91 @@ button_widget_set_dnd_highlight(ButtonWidget *button, gboolean highlight)
 			gdk_pixmap_unref(button->cache);
 		button->cache = NULL;
 
-		panel_widget_draw_icon(PANEL_WIDGET(GTK_WIDGET(button)->parent),
-				       button);
+		panel_widget_draw_icon (PANEL_WIDGET(GTK_WIDGET(button)->parent), button);
 	}
 }
 
-static void
-button_widget_real_draw(GtkWidget *widget, GdkRectangle *area)
-{
-	if(widget->parent && IS_PANEL_WIDGET(widget->parent))
-		panel_widget_draw_icon(PANEL_WIDGET(widget->parent), BUTTON_WIDGET(widget));
-
-}
-
 void
 button_widget_draw(ButtonWidget *button, guchar *rgb, int rowstride)
 {
 	GtkWidget *widget, *pwidget;
 	PanelWidget *panel;
-	int size, off, border;
+	GdkPixbuf *pb = NULL;
+	int size, off;
 
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
 	g_return_if_fail(rgb != NULL);
 	g_return_if_fail(rowstride >= 0);
 
 	widget = GTK_WIDGET(button);
 	panel = PANEL_WIDGET(widget->parent);
 	size = panel->sz;
-	/*offset for pressed buttons*/
+	/* offset for pressed buttons */
 	off = (button->in_button && button->pressed) ?
-		SCALE(tile_depth[button->tile]) : 0;
-	/*border to not draw when drawing a tile*/
-	border = tiles_enabled[button->tile] ?
-		SCALE(tile_border[button->tile]) : 0;
+		SCALE(BUTTON_WIDGET_DISPLACEMENT) : 0;
 	 
 	button->size = size;
 	
 	pwidget = widget->parent;
-	
-	if(tiles_enabled[button->tile]) {
-		GdkPixbuf *pb = NULL;
-		if (button->pressed &&
-		    button->in_button) {
-			/* Pressed down */
-			if(!global_config.saturate_when_over ||
-			   !button->in_button) {
-				pb = tiles.tiles_down[button->tile];
-			} else {
-				pb = tiles.tiles_down_hc[button->tile];
-			}
-		} else if ( ! global_config.tile_when_over ||
-			    button->in_button) {
-			/* not pressed */
-			if( ! global_config.saturate_when_over ||
-			    ! button->in_button) {
-				pb = tiles.tiles_up[button->tile];
-			} else {
-				pb = tiles.tiles_up_hc[button->tile];
-			}
-		}
 
-		if(pb != NULL) {
-			GdkPixbuf *scaled_pb;
-			double affine[6];
-			GdkInterpType interp;
-
-			if (global_config.fast_button_scaling)
-				interp = GDK_INTERP_NEAREST;
-			else
-				interp = GDK_INTERP_HYPER;
-
-			scaled_pb = scale_pixbuf_to_square (pb, size,
-							    NULL, NULL,
-							    interp);
-
-			art_affine_identity (affine);
-
-			transform_pixbuf (rgb, 0, 0, size, size,
-					  rowstride, scaled_pb, affine,
-					  ART_FILTER_NEAREST, NULL);
-
-			gdk_pixbuf_unref (scaled_pb);
-		}
+	if(!global_config.highlight_when_over || !button->in_button) {
+		pb = button->pixbuf;
+	} else {
+#ifdef BUTTON_WIDGET_DEBUG
+	printf ("Using highlighted pixbuf\n");
+#endif
+		pb = button->pixbuf_hc;
 	}
+	if(pb != NULL) {
+		double affine[6];
+		int w, h;
+		GdkPixbuf *scaled_pb;
+		GdkInterpType interp;
 
-	if (pixmaps_enabled[button->tile]) {
-		GdkPixbuf *pb = NULL;
-		if(!global_config.saturate_when_over || !button->in_button) {
-			pb = button->pixbuf;
-		} else {
-			pb = button->pixbuf_hc;
-		}
-		if(pb != NULL) {
-			double affine[6];
-			int w, h;
-			GdkPixbuf *scaled_pb;
-			GdkInterpType interp;
+		interp = GDK_INTERP_HYPER;
 
-			if (global_config.fast_button_scaling)
-				interp = GDK_INTERP_NEAREST;
-			else
-				interp = GDK_INTERP_HYPER;
+		scaled_pb = scale_pixbuf_to_square (pb, size, &w, &h,
+						    interp);
 
-			scaled_pb = scale_pixbuf_to_square (pb, size, &w, &h,
-							    interp);
+		art_affine_translate(affine, 
+				     off + (size-w)/2, 
+				     off + (size-h)/2);
 
-			art_affine_translate(affine,
-					     -border+off + (size-w)/2,
-					     -border+off + (size-h)/2);
+		transform_pixbuf(rgb,
+			         0, 0,
+			         size, size,
+			         rowstride,
+			         scaled_pb,
+			         affine, ART_FILTER_NEAREST, NULL);
 
-			transform_pixbuf((rgb+border*rowstride+border*3),
-				         0, 0,
-				         size-2*border, size-2*border,
-				         rowstride,
-				         scaled_pb,
-				         affine, ART_FILTER_NEAREST, NULL);
-
-			gdk_pixbuf_unref (scaled_pb);
-		}
+		gdk_pixbuf_unref (scaled_pb);
 	}
 }
 
 /* draw the xlib part (arrow/text/dndhighlight) */
+
 void
 button_widget_draw_xlib(ButtonWidget *button, GdkPixmap *pixmap)
 {
 	GtkWidget *widget, *pwidget;
 	GdkGC *gc;
-	int size, off;
+	int size;
+	int off; 
 
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
 	g_return_if_fail(pixmap != NULL);
 
 	widget = GTK_WIDGET(button);
 	size = button->size;
 
-	/*offset for pressed buttons*/
+	/* offset for pressed buttons */
 	off = (button->in_button && button->pressed) ?
-		SCALE(tile_depth[button->tile]) : 0;
-	 
+		SCALE(BUTTON_WIDGET_DISPLACEMENT) : 0; 
 	gc = gdk_gc_new(pixmap);
 	
 	pwidget = widget->parent;
-	/*draw text*/
-	if (!pixmaps_enabled[button->tile] ||
-	    always_text[button->tile] ||
-	    !button->pixbuf) {
-		char *text = g_strdup(button->text);
-		int twidth,theight;
-		GdkFont *font;
-		GdkRectangle rect;
-	         
-	        rect.x = 0;
-	        rect.y = 0;
-	        rect.width = widget->allocation.width;
-	        rect.height = widget->allocation.height;
-
-		if(!text) text = g_strdup("XXX");
-		
-		font = gdk_fontset_load(_("-*-helvetica-medium-r-normal-*-8-*-*-*-*-*-*-*"));
-		if(!font)
-			font = gdk_font_load("fixed");
-		if(!font)
-			font = widget->style->font;
-		
-
-		gdk_gc_set_clip_rectangle (gc, &rect);
-
-		twidth = gdk_string_width(font,text);
-		theight = gdk_string_height(font,text);
-		if(twidth>size)
-			twidth = size;
-		
-		gdk_gc_set_foreground(gc,&widget->style->black);
-		gdk_draw_rectangle(pixmap,gc,TRUE,
-				   (widget->allocation.width/2)-(twidth/2)+off-1,
-				   (widget->allocation.height/2)-(theight/2)-1+off,
-				   twidth+2,
-				   theight+2);
-		gdk_gc_set_foreground(gc,&widget->style->white);
-		gdk_draw_string(pixmap,font,gc,
-				(widget->allocation.width/2)-(twidth/2)+off,
-				(widget->allocation.height/2)+(theight/2)+off,
-				text);
-		gdk_gc_set_foreground(gc,&widget->style->black);
-		gdk_gc_set_clip_rectangle (gc, NULL);
-		if(font!=widget->style->font)
-			gdk_font_unref(font);
-		g_free(text);
-	}
-
 	
 	if(button->arrow) {
 		int i;
@@ -794,7 +670,7 @@ button_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	ButtonWidget *button_widget;
 
 	g_return_if_fail (widget != NULL);
-	g_return_if_fail (IS_BUTTON_WIDGET (widget));
+	g_return_if_fail (BUTTON_IS_WIDGET (widget));
 
 	button_widget = BUTTON_WIDGET (widget);
 
@@ -815,7 +691,7 @@ button_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 
 
 static void
-button_widget_init (ButtonWidget *button)
+button_widget_instance_init (ButtonWidget *button)
 {
 	buttons = g_list_prepend(buttons,button);
 
@@ -824,9 +700,9 @@ button_widget_init (ButtonWidget *button)
 	button->pixbuf = NULL;
 	button->pixbuf_hc = NULL;
 	
-	button->tile = 0;
+	button->pobject = 0;
 	button->arrow = 0;
-	button->orient = ORIENT_UP;
+	button->orient = PANEL_ORIENT_UP;
 	
 	button->pressed = FALSE;
 	button->in_button = FALSE;
@@ -835,9 +711,9 @@ button_widget_init (ButtonWidget *button)
 	
 	button->pressed_timeout = 0;
 	
-	gtk_signal_connect(GTK_OBJECT(button),"destroy",
-			   GTK_SIGNAL_FUNC(button_widget_destroy),
-			   NULL);
+	g_signal_connect (G_OBJECT(button),"destroy",
+			  G_CALLBACK (button_widget_destroy),
+			  NULL);
 }
 
 static gboolean
@@ -846,7 +722,7 @@ pressed_timeout_func(gpointer data)
 	ButtonWidget *button;
 
 	g_return_val_if_fail (data != NULL, FALSE);
-	g_return_val_if_fail (IS_BUTTON_WIDGET (data), FALSE);
+	g_return_val_if_fail (BUTTON_IS_WIDGET (data), FALSE);
 
 	button = BUTTON_WIDGET (data);
 	
@@ -861,7 +737,7 @@ button_widget_button_press (GtkWidget *widget, GdkEventButton *event)
 	ButtonWidget *button;
 
 	g_return_val_if_fail (widget != NULL, FALSE);
-	g_return_val_if_fail (IS_BUTTON_WIDGET (widget), FALSE);
+	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
 	g_return_val_if_fail (event != NULL, FALSE);
 
 	button = BUTTON_WIDGET (widget);
@@ -882,7 +758,7 @@ static gboolean
 button_widget_button_release (GtkWidget *widget, GdkEventButton *event)
 {
 	g_return_val_if_fail (widget != NULL, FALSE);
-	g_return_val_if_fail (IS_BUTTON_WIDGET (widget), FALSE);
+	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
 	g_return_val_if_fail (event != NULL, FALSE);
 
 	if (event->button == 1) {
@@ -900,7 +776,7 @@ button_widget_enter_notify (GtkWidget *widget, GdkEventCrossing *event)
 	GtkWidget *event_widget;
 
 	g_return_val_if_fail (widget != NULL, FALSE);
-	g_return_val_if_fail (IS_BUTTON_WIDGET (widget), FALSE);
+	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
 	g_return_val_if_fail (event != NULL, FALSE);
 
 	event_widget = gtk_get_event_widget ((GdkEvent*) event);
@@ -909,14 +785,11 @@ button_widget_enter_notify (GtkWidget *widget, GdkEventCrossing *event)
 	    (event->detail != GDK_NOTIFY_INFERIOR)) {
 		ButtonWidget *button = BUTTON_WIDGET (widget);
 		button->in_button = TRUE;
-		if(global_config.tile_when_over ||
-		   global_config.saturate_when_over) {
-			if(button->cache)
-				gdk_pixmap_unref(button->cache);
-			button->cache = NULL;
-			panel_widget_draw_icon(PANEL_WIDGET(widget->parent),
-					       button);
-		}
+		if (button->cache)
+			gdk_pixmap_unref (button->cache);
+		button->cache = NULL;
+		panel_widget_draw_icon (PANEL_WIDGET(widget->parent),
+					button);
 	}
 
 	return FALSE;
@@ -929,7 +802,7 @@ button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 	ButtonWidget *button;
 
 	g_return_val_if_fail (widget != NULL, FALSE);
-	g_return_val_if_fail (IS_BUTTON_WIDGET (widget), FALSE);
+	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
 	g_return_val_if_fail (event != NULL, FALSE);
 
 	event_widget = gtk_get_event_widget ((GdkEvent*) event);
@@ -940,13 +813,12 @@ button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 	    (event->detail != GDK_NOTIFY_INFERIOR) &&
 	    (!button->ignore_leave)) {
 		button->in_button = FALSE;
-		if(global_config.tile_when_over ||
-		   global_config.saturate_when_over) {
-			if(button->cache)
-				gdk_pixmap_unref(button->cache);
+		if (global_config.highlight_when_over) {
+			if (button->cache)
+				gdk_pixmap_unref (button->cache);
 			button->cache = NULL;
-			panel_widget_draw_icon(PANEL_WIDGET(widget->parent),
-					       button);
+			panel_widget_draw_icon (PANEL_WIDGET(widget->parent),
+						button);
 		}
 	}
 
@@ -957,15 +829,15 @@ button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 void
 button_widget_clicked(ButtonWidget *button)
 {
-	gtk_signal_emit(GTK_OBJECT(button),
-			button_widget_signals[CLICKED_SIGNAL]);
+	g_signal_emit (G_OBJECT(button),
+		       button_widget_signals[CLICKED_SIGNAL], 0);
 }
 
 static void
 button_widget_pressed(ButtonWidget *button)
 {
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
 
 	button->pressed = TRUE;
 	if(button->cache)
@@ -979,7 +851,7 @@ static void
 button_widget_unpressed(ButtonWidget *button)
 {
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
 
 	button->pressed = FALSE;
 	if(button->cache)
@@ -996,54 +868,56 @@ void
 button_widget_down(ButtonWidget *button)
 {
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
 
 	if(!button->pressed)
-		gtk_signal_emit(GTK_OBJECT(button),
-				button_widget_signals[PRESSED_SIGNAL]);
+		g_signal_emit(G_OBJECT(button),
+			      button_widget_signals[PRESSED_SIGNAL], 0);
 }
 void
 button_widget_up(ButtonWidget *button)
 {
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
 
 	if(button->pressed)
-		gtk_signal_emit(GTK_OBJECT(button),
-				button_widget_signals[UNPRESSED_SIGNAL]);
+		g_signal_emit(G_OBJECT(button),
+			      button_widget_signals[UNPRESSED_SIGNAL], 0);
 }
 
 static GdkPixbuf *
 make_hc_pixbuf(GdkPixbuf *pb)
 {
-	GdkPixbuf *newpb;
+	GdkPixbuf *new;
 	if(!pb)
 		return NULL;
-
-	newpb = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pb),
+#ifdef BUTTON_WIDGET_DEBUG
+	printf ("Creating highlight pixbuf\n");
+#endif
+	new = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pb),
 			     gdk_pixbuf_get_has_alpha(pb),
 			     gdk_pixbuf_get_bits_per_sample(pb),
 			     gdk_pixbuf_get_width(pb),
 			     gdk_pixbuf_get_height(pb));
-	do_colorshift(newpb, pb, 30);
-	/*do_saturate_darken (newpb, pb, (int)(1.00*255), (int)(1.15*255));*/
+	do_colorshift(new, pb, 30);
+	/*do_saturate_darken (new, pb, (int)(1.00*255), (int)(1.15*255));*/
 
-	return newpb;
+	return new;
 }
 
 
 GtkWidget*
 button_widget_new(const char *filename,
 		  int size,
-		  int tile,
+		  int pobject,
 		  gboolean arrow,
-		  PanelOrientType orient,
+		  PanelOrient orient,
 		  const char *text)
 {
 	ButtonWidget *button;
 
-	g_return_val_if_fail(tile >= 0, NULL);
-	g_return_val_if_fail(tile < LAST_TILE, NULL);
+	g_return_val_if_fail(pobject >= 0, NULL);
+	g_return_val_if_fail(pobject < LAST_POBJECT, NULL);
 
 	button = BUTTON_WIDGET (gtk_type_new (button_widget_get_type ()));
 	
@@ -1051,7 +925,7 @@ button_widget_new(const char *filename,
 	button->pixbuf_hc = make_hc_pixbuf (button->pixbuf);
 	button->filename = g_strdup (filename);
 	button->size = size;
-	button->tile = tile;
+	button->pobject = pobject;
 	button->arrow = arrow ? 1 : 0;
 	button->orient = orient;
 	button->text = text ? g_strdup (text) : NULL;
@@ -1065,7 +939,7 @@ gboolean
 button_widget_set_pixmap(ButtonWidget *button, const char *pixmap, int size)
 {
 	g_return_val_if_fail(button != NULL, FALSE);
-	g_return_val_if_fail(IS_BUTTON_WIDGET(button), FALSE);
+	g_return_val_if_fail(BUTTON_IS_WIDGET(button), FALSE);
 
 	if (size < 0)
 		size = PANEL_WIDGET(GTK_WIDGET(button)->parent)->sz;
@@ -1098,7 +972,7 @@ void
 button_widget_set_text(ButtonWidget *button, const char *text)
 {
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
 
 	g_free(button->text);
 	button->text = text?g_strdup(text):NULL;
@@ -1113,16 +987,16 @@ button_widget_set_text(ButtonWidget *button, const char *text)
 
 void
 button_widget_set_params(ButtonWidget *button,
-			 int tile,
+			 int pobject,
 			 gboolean arrow,
-			 PanelOrientType orient)
+			 PanelOrient orient)
 {
 	g_return_if_fail(button != NULL);
-	g_return_if_fail(IS_BUTTON_WIDGET(button));
-	g_return_if_fail(tile >= 0);
-	g_return_if_fail(tile < LAST_TILE);
+	g_return_if_fail(BUTTON_IS_WIDGET(button));
+	g_return_if_fail(pobject >= 0);
+	g_return_if_fail(pobject < LAST_POBJECT);
 
-	button->tile = tile;
+	button->pobject = pobject;
 	button->arrow = arrow?1:0;
 	button->orient = orient;
 
@@ -1135,61 +1009,6 @@ button_widget_set_params(ButtonWidget *button,
 			       button);
 }
 
-void
-button_widget_load_tile(int tile, const char *tile_up, const char *tile_down,
-			int border, int depth)
-{
-	GdkPixbuf *pb;
-
-	g_return_if_fail(tile >= 0);
-	g_return_if_fail(tile < LAST_TILE);
-	g_return_if_fail(tile_up != NULL);
-	g_return_if_fail(tile_down != NULL);
-
-	if(tiles.tiles_up[tile])
-		gdk_pixbuf_unref(tiles.tiles_up[tile]);
-	if(tiles.tiles_up_hc[tile])
-		gdk_pixbuf_unref(tiles.tiles_up_hc[tile]);
-
-	pb = loadup_file(tile_up);
-	tiles.tiles_up[tile] = pb;
-	tiles.tiles_up_hc[tile] = make_hc_pixbuf(pb);
-
-	if(tiles.tiles_down[tile])
-		gdk_pixbuf_unref(tiles.tiles_down[tile]);
-	if(tiles.tiles_down_hc[tile])
-		gdk_pixbuf_unref(tiles.tiles_down_hc[tile]);
-
-	pb = loadup_file(tile_down);
-	tiles.tiles_down[tile] = pb;
-	tiles.tiles_down_hc[tile] = make_hc_pixbuf(pb);
-
-	tile_border[tile] = border;
-	tile_depth[tile] = depth;
-
-	button_widget_redo_all ();
-}
-
-void
-button_widget_set_flags(int tile,
-			gboolean enable_tiles,
-			gboolean enable_pixmaps,
-			gboolean text_always)
-{
-	g_return_if_fail (tile >= 0);
-	g_return_if_fail (tile < LAST_TILE);
-
-	if(tiles_enabled[tile] != enable_tiles ||
-	   pixmaps_enabled[tile] != enable_pixmaps ||
-	   always_text[tile] != text_always) {
-		tiles_enabled[tile] = enable_tiles;
-		pixmaps_enabled[tile] = enable_pixmaps;
-		always_text[tile] = text_always;
-
-		button_widget_redo_all ();
-	}
-}
-
 void
 button_widget_redo_all (void)
 {
