@@ -5,7 +5,7 @@
  *           George Lebl
  *
  */
-
+#include <stdio.h>
 #include "config.h"
 #include "drawer-widget.h"
 #include "border-widget.h"
@@ -17,19 +17,21 @@
 extern GlobalConfig global_config;
 extern int pw_minimized_size;
 
+#undef DRAWER_WIDGET_DEBUG
+
 static void drawer_pos_class_init (DrawerPosClass *klass);
-static void drawer_pos_init (DrawerPos *pos);
+static void drawer_pos_instance_init (DrawerPos *pos);
 
 static void drawer_pos_set_hidebuttons (BasePWidget *basep);
-static PanelOrientType drawer_pos_get_applet_orient (BasePWidget *basep);
+static PanelOrient drawer_pos_get_applet_orient (BasePWidget *basep);
 
-static PanelOrientType drawer_pos_get_hide_orient (BasePWidget *basep);
+static PanelOrient drawer_pos_get_hide_orient (BasePWidget *basep);
 static void drawer_pos_get_hide_pos (BasePWidget *basep,
-				     PanelOrientType hide_orient,
+				     PanelOrient hide_orient,
 				     int *x, int *y,
 				     int w, int h);
 static void drawer_pos_get_hide_size (BasePWidget *basep, 
-				      PanelOrientType hide_orient,
+				      PanelOrient hide_orient,
 				      int *w, int *h);
 
 static void drawer_pos_get_pos(BasePWidget *basep,
@@ -47,30 +49,29 @@ static void drawer_pos_hidebutton_click (BasePWidget *basep);
 
 static void drawer_pos_pre_convert_hook (BasePWidget *basep);
 
-static BasePPosClass *parent_class;
+static BasePPosClass *drawer_pos_parent_class;
 
-GtkType
+GType
 drawer_pos_get_type (void)
 {
-	static GtkType drawer_pos_type = 0;
-
-	if (drawer_pos_type == 0) {
-		GtkTypeInfo drawer_pos_info = {
-			"DrawerPos",
-			sizeof (DrawerPos),
+	static GType object_type = 0;
+	if (object_type == 0) {
+		static const GTypeInfo object_info = {
 			sizeof (DrawerPosClass),
-			(GtkClassInitFunc) drawer_pos_class_init,
-			(GtkObjectInitFunc) drawer_pos_init,
-			NULL,
-			NULL,
-			NULL
+ 	                (GBaseInitFunc)         NULL,
+       		        (GBaseFinalizeFunc)     NULL,
+       		        (GClassInitFunc)        drawer_pos_class_init,
+                    	NULL,                   /* class_finalize */
+                    	NULL,                   /* class_data */
+                    	sizeof (DrawerPos),
+                    	0,                      /* n_preallocs */
+                    	(GInstanceInitFunc)    drawer_pos_instance_init 
 		};
-
-		drawer_pos_type = gtk_type_unique (TYPE_BASEP_POS,
-						   &drawer_pos_info);
+		object_type = g_type_register_static (BASEP_TYPE_POS, "DrawerPos", &object_info, 0);
+		drawer_pos_parent_class = g_type_class_ref (BASEP_TYPE_POS);
 	}
 
-	return drawer_pos_type;
+	return object_type;
 }
 
 static void
@@ -79,8 +80,6 @@ drawer_pos_class_init (DrawerPosClass *klass)
 	/*GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);*/
 	BasePPosClass *pos_class = BASEP_POS_CLASS(klass);
 
-	parent_class = gtk_type_class(TYPE_BASEP_POS);
-
 	/* fill out the virtual funcs */
 	pos_class->set_hidebuttons = drawer_pos_set_hidebuttons;
 	pos_class->get_applet_orient = drawer_pos_get_applet_orient;
@@ -100,31 +99,31 @@ drawer_pos_class_init (DrawerPosClass *klass)
 }
 
 static void
-drawer_pos_init (DrawerPos *pos) { }
+drawer_pos_instance_init (DrawerPos *pos) { }
 
 static void
 drawer_pos_set_hidebuttons (BasePWidget *basep)
 {
 	switch(DRAWER_POS(basep->pos)->orient) {
-	case ORIENT_UP:
+	case PANEL_ORIENT_UP:
 		gtk_widget_show(basep->hidebutton_n);
 		gtk_widget_hide(basep->hidebutton_e);
 		gtk_widget_hide(basep->hidebutton_w);
 		gtk_widget_hide(basep->hidebutton_s);
 		break;
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_DOWN:
 		gtk_widget_hide(basep->hidebutton_n);
 		gtk_widget_hide(basep->hidebutton_e);
 		gtk_widget_hide(basep->hidebutton_w);
 		gtk_widget_show(basep->hidebutton_s);
 		break;
-	case ORIENT_LEFT:
+	case PANEL_ORIENT_LEFT:
 		gtk_widget_hide(basep->hidebutton_n);
 		gtk_widget_hide(basep->hidebutton_e);
 		gtk_widget_show(basep->hidebutton_w);
 		gtk_widget_hide(basep->hidebutton_s);
 		break;
-	case ORIENT_RIGHT:
+	case PANEL_ORIENT_RIGHT:
 		gtk_widget_hide(basep->hidebutton_n);
 		gtk_widget_show(basep->hidebutton_e);
 		gtk_widget_hide(basep->hidebutton_w);
@@ -133,7 +132,7 @@ drawer_pos_set_hidebuttons (BasePWidget *basep)
 	}
 }
 
-static PanelOrientType
+static PanelOrient
 drawer_pos_get_applet_orient (BasePWidget *basep)
 {
 	PanelWidget *panel = PANEL_WIDGET (basep->panel);
@@ -146,19 +145,19 @@ drawer_pos_get_applet_orient (BasePWidget *basep)
 	if(porient == PANEL_VERTICAL) {
 		if (x > (multiscreen_width (basep->screen)/2 +
 			 multiscreen_x (basep->screen)))
-			return ORIENT_LEFT;
+			return PANEL_ORIENT_LEFT;
 		else
-			return ORIENT_RIGHT;
+			return PANEL_ORIENT_RIGHT;
 	} else {
 		if (y > (multiscreen_height (basep->screen)/2 +
 			 multiscreen_y (basep->screen)))
-			return ORIENT_UP;
+			return PANEL_ORIENT_UP;
 		else
-			return ORIENT_DOWN;
+			return PANEL_ORIENT_DOWN;
 	}
 }
 
-static PanelOrientType
+static PanelOrient
 drawer_pos_get_hide_orient (BasePWidget *basep)
 {
 	DrawerPos *pos = DRAWER_POS (basep->pos);
@@ -167,19 +166,19 @@ drawer_pos_get_hide_orient (BasePWidget *basep)
 	switch (basep->state) {
 	case BASEP_AUTO_HIDDEN:
 		switch (pos->orient) {
-		case ORIENT_UP: return ORIENT_DOWN;
-		case ORIENT_RIGHT: return ORIENT_LEFT;
-		case ORIENT_DOWN: return ORIENT_UP;
-		case ORIENT_LEFT: return ORIENT_RIGHT;
+		case PANEL_ORIENT_UP: return PANEL_ORIENT_DOWN;
+		case PANEL_ORIENT_RIGHT: return PANEL_ORIENT_LEFT;
+		case PANEL_ORIENT_DOWN: return PANEL_ORIENT_UP;
+		case PANEL_ORIENT_LEFT: return PANEL_ORIENT_RIGHT;
 		}
 		g_assert_not_reached ();
 		break;
 	case BASEP_HIDDEN_LEFT:
 		return (panel->orient == PANEL_HORIZONTAL)
-			? ORIENT_LEFT : ORIENT_UP;
+			? PANEL_ORIENT_LEFT : PANEL_ORIENT_UP;
 	case BASEP_HIDDEN_RIGHT:
 		return (panel->orient == PANEL_HORIZONTAL)
-			? ORIENT_RIGHT : ORIENT_DOWN;
+			? PANEL_ORIENT_RIGHT : PANEL_ORIENT_DOWN;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -191,7 +190,7 @@ drawer_pos_get_hide_orient (BasePWidget *basep)
 void
 drawer_widget_open_drawer (DrawerWidget *drawer, GtkWidget *parentp)
 {
-	if (IS_BASEP_WIDGET (parentp))
+	if (BASEP_IS_WIDGET (parentp))
 		BASEP_WIDGET (parentp)->drawers_open++;
 	basep_widget_explicit_show (BASEP_WIDGET (drawer));
 }
@@ -205,17 +204,17 @@ drawer_widget_close_drawer (DrawerWidget *drawer, GtkWidget *parentp)
 		gdk_window_raise(GTK_WIDGET(parentp)->window);
 
 	switch (DRAWER_POS (basep->pos)->orient) {
-	case ORIENT_UP:
-	case ORIENT_LEFT:
+	case PANEL_ORIENT_UP:
+	case PANEL_ORIENT_LEFT:
 		basep_widget_explicit_hide (basep, BASEP_HIDDEN_RIGHT);
 		break;
-	case ORIENT_RIGHT:
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_RIGHT:
+	case PANEL_ORIENT_DOWN:
 		basep_widget_explicit_hide (basep, BASEP_HIDDEN_LEFT);
 		break;
 	}
 
-	if (IS_BASEP_WIDGET (parentp))
+	if (BASEP_IS_WIDGET (parentp))
 		BASEP_WIDGET (parentp)->drawers_open--;
 }
 
@@ -299,19 +298,19 @@ drawer_pos_get_pos(BasePWidget *basep,
 		ph = ppanel->allocation.height;
 
 		switch(pos->orient) {
-		case ORIENT_UP:
+		case PANEL_ORIENT_UP:
 			*x = bx+(bw-width)/2;
 			*y = py - height;
 			break;
-		case ORIENT_DOWN:
+		case PANEL_ORIENT_DOWN:
 			*x = bx+(bw-width)/2;
 			*y = py + ph;
 			break;
-		case ORIENT_LEFT:
+		case PANEL_ORIENT_LEFT:
 			*x = px - width;
 			*y = by+(bh-height)/2;
 			break;
-		case ORIENT_RIGHT:
+		case PANEL_ORIENT_RIGHT:
 			*x = px + pw;
 			*y = by+(bh-height)/2;
 			break;
@@ -321,7 +320,7 @@ drawer_pos_get_pos(BasePWidget *basep,
 
 static void
 drawer_pos_get_hide_pos (BasePWidget *basep,
-			 PanelOrientType hide_orient,
+			 PanelOrient hide_orient,
 			 int *x, int *y,
 			 int w, int h)
 {
@@ -334,16 +333,16 @@ drawer_pos_get_hide_pos (BasePWidget *basep,
 
 static void
 drawer_pos_get_hide_size (BasePWidget *basep, 
-			  PanelOrientType hide_orient,
+			  PanelOrient hide_orient,
 			  int *w, int *h)
 {
 	switch (hide_orient) {
-	case ORIENT_UP:
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_UP:
+	case PANEL_ORIENT_DOWN:
 		*h = 1;
 		break;
-	case ORIENT_RIGHT:
-	case ORIENT_LEFT:
+	case PANEL_ORIENT_RIGHT:
+	case PANEL_ORIENT_LEFT:
 		*w = 1;
 		break;
 	}
@@ -359,7 +358,7 @@ drawer_pos_pre_convert_hook (BasePWidget *basep)
 
 void
 drawer_widget_change_params (DrawerWidget *drawer,
-			     PanelOrientType orient,
+			     PanelOrient orient,
 			     BasePMode mode,
 			     BasePState state,
 			     BasePLevel level,
@@ -378,12 +377,12 @@ drawer_widget_change_params (DrawerWidget *drawer,
 	DrawerPos *pos = DRAWER_POS (BASEP_WIDGET (drawer)->pos);
 
 	switch (orient) {
-	case ORIENT_UP:
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_UP:
+	case PANEL_ORIENT_DOWN:
 		porient = PANEL_VERTICAL;
 		break;
-	case ORIENT_LEFT:
-	case ORIENT_RIGHT:
+	case PANEL_ORIENT_LEFT:
+	case PANEL_ORIENT_RIGHT:
 	default:
 		porient = PANEL_HORIZONTAL;
 		break;
@@ -395,21 +394,21 @@ drawer_widget_change_params (DrawerWidget *drawer,
 	if (state != BASEP_WIDGET (drawer)->state ||
 	    pos->orient != orient) {
 		if (state == BASEP_HIDDEN_LEFT &&
-		    (orient == ORIENT_LEFT ||
-		     orient == ORIENT_UP))
+		    (orient == PANEL_ORIENT_LEFT ||
+		     orient == PANEL_ORIENT_UP))
 			state = BASEP_HIDDEN_RIGHT;
 		else if (state == BASEP_HIDDEN_RIGHT &&
-			 (orient == ORIENT_RIGHT ||
-			  orient == ORIENT_DOWN))
+			 (orient == PANEL_ORIENT_RIGHT ||
+			  orient == PANEL_ORIENT_DOWN))
 			 state = BASEP_HIDDEN_LEFT;
 	}
 
 	if (pos->orient != orient) {
 		pos->orient = orient;
 #if 0
-		gtk_signal_emit (GTK_OBJECT (drawer),
-				 drawer_pos_signals[ORIENT_CHANGE_SIGNAL],
-				 orient);
+		g_signal_emit (G_OBJECT (drawer),
+			       drawer_pos_signals[ORIENT_CHANGE_SIGNAL],
+			       0, orient);
 #endif
 	}
 
@@ -434,7 +433,7 @@ drawer_widget_change_params (DrawerWidget *drawer,
 
 void
 drawer_widget_change_orient (DrawerWidget *drawer,
-			     PanelOrientType orient)
+			     PanelOrient orient)
 {
 	DrawerPos *pos = DRAWER_POS (drawer->pos);
 	if (pos->orient != orient) {
@@ -459,7 +458,7 @@ drawer_widget_change_orient (DrawerWidget *drawer,
 }
 
 GtkWidget *
-drawer_widget_new (PanelOrientType orient,
+drawer_widget_new (PanelOrient orient,
 		   BasePMode mode,
 		   BasePState state,
 		   BasePLevel level,
@@ -478,14 +477,14 @@ drawer_widget_new (PanelOrientType orient,
 	DrawerPos *pos;
 	PanelOrientation porient;
 
-	drawer = gtk_type_new (TYPE_DRAWER_WIDGET);
-	drawer->pos = gtk_type_new (TYPE_DRAWER_POS);
+	drawer = gtk_type_new (DRAWER_TYPE_WIDGET);
+	drawer->pos = gtk_type_new (DRAWER_TYPE_POS);
 	pos = DRAWER_POS (drawer->pos);
 	pos->orient = orient;
 
 	switch (orient) {
-	case ORIENT_UP:
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_UP:
+	case PANEL_ORIENT_DOWN:
 		porient = PANEL_VERTICAL;
 		break;
 	default:
