@@ -10,22 +10,22 @@
 
 #include "floating-widget.h"
 #include "border-widget.h"
+#include "panel-marshal.h"
 #include "panel_config_global.h"
 #include "foobar-widget.h"
 #include "panel-util.h"
-
-extern GlobalConfig global_config;
-extern int pw_minimized_size;
+#include "panel-gconf.h"
+#include "multiscreen-stuff.h"
 
 static void floating_pos_class_init (FloatingPosClass *klass);
-static void floating_pos_init (FloatingPos *pos);
+static void floating_pos_instance_init (FloatingPos *pos);
 
 static void floating_pos_set_hidebuttons (BasePWidget *basep);
-static PanelOrientType floating_pos_get_applet_orient (BasePWidget *basep);
+static PanelOrient floating_pos_get_applet_orient (BasePWidget *basep);
 
-static PanelOrientType floating_pos_get_hide_orient (BasePWidget *basep);
+static PanelOrient floating_pos_get_hide_orient (BasePWidget *basep);
 static void floating_pos_get_hide_pos (BasePWidget *basep,
-				     PanelOrientType hide_orient,
+				     PanelOrient hide_orient,
 				     int *x, int *y,
 				     int w, int h);
 
@@ -35,10 +35,11 @@ static void floating_pos_get_pos(BasePWidget *basep,
 
 static void floating_pos_set_pos (BasePWidget *basep,
 				  int x, int y,
-				  int w, int h);
+				  int w, int h,
+				  gboolean force);
 
 static void floating_pos_get_hide_size (BasePWidget *basep,
-					PanelOrientType hide_orient,
+					PanelOrient hide_orient,
 					int *x, int *y);
 
 static void floating_pos_get_menu_pos (BasePWidget *basep,
@@ -53,30 +54,31 @@ static void floating_pos_pre_convert_hook (BasePWidget *basep);
 static void floating_pos_show_hide_left (BasePWidget *basep);
 static void floating_pos_show_hide_right (BasePWidget *basep);
 
-static BasePPosClass *parent_class;
+static BasePPosClass *floating_pos_parent_class;
 
-GtkType
+GType
 floating_pos_get_type (void)
 {
-	static GtkType floating_pos_type = 0;
+	static GType object_type= 0;
 
-	if (floating_pos_type == 0) {
-		GtkTypeInfo floating_pos_info = {
-			"FloatingPos",
-			sizeof (FloatingPos),
-			sizeof (FloatingPosClass),
-			(GtkClassInitFunc) floating_pos_class_init,
-			(GtkObjectInitFunc) floating_pos_init,
-			NULL,
-			NULL,
-			NULL
+	if (object_type == 0) {
+		static const GTypeInfo object_info = {
+                    sizeof (FloatingPosClass),
+                    (GBaseInitFunc)         NULL,
+                    (GBaseFinalizeFunc)     NULL,
+                    (GClassInitFunc)        floating_pos_class_init,
+                    NULL,                   /* class_finalize */
+                    NULL,                   /* class_data */
+                    sizeof (FloatingPos),
+                    0,                      /* n_preallocs */
+                    (GInstanceInitFunc)     floating_pos_instance_init
 		};
 
-		floating_pos_type = gtk_type_unique (TYPE_BASEP_POS,
-						     &floating_pos_info);
+		object_type = g_type_register_static (BASEP_TYPE_POS, "FloatingPos", &object_info, 0);
+		floating_pos_parent_class = g_type_class_ref (BASEP_TYPE_POS);
 	}
 
-	return floating_pos_type;
+	return object_type;
 }
 
 enum {
@@ -88,24 +90,21 @@ static guint floating_pos_signals[LAST_SIGNAL] = { 0 };
 static void
 floating_pos_class_init (FloatingPosClass *klass)
 {
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);
-	BasePPosClass *pos_class = BASEP_POS_CLASS(klass);
-
-	parent_class = gtk_type_class(TYPE_BASEP_POS);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	BasePPosClass *pos_class = BASEP_POS_CLASS (klass);
 
 	floating_pos_signals[COORDS_CHANGE_SIGNAL] =
-		gtk_signal_new ("floating_coords_change",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (FloatingPosClass,
-						   coords_change),
-				gtk_marshal_NONE__INT_INT,
-				GTK_TYPE_NONE,
-				2, GTK_TYPE_INT, GTK_TYPE_INT);
-	
-	gtk_object_class_add_signals (object_class,
-				      floating_pos_signals,
-				      LAST_SIGNAL);
+		g_signal_new ("floating_coords_change",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (FloatingPosClass, coords_change),
+			      NULL,
+			      NULL,
+			      panel_marshal_INT__INT,
+			      G_TYPE_NONE,
+			      2,
+			      G_TYPE_INT,
+			      G_TYPE_INT);
 	
 	/* fill out the virtual funcs */
 	pos_class->set_hidebuttons = floating_pos_set_hidebuttons;
@@ -124,7 +123,7 @@ floating_pos_class_init (FloatingPosClass *klass)
 }
 
 static void
-floating_pos_init (FloatingPos *pos) { }
+floating_pos_instance_init (FloatingPos *pos) { }
 
 static void
 floating_pos_set_hidebuttons (BasePWidget *basep)
@@ -142,21 +141,23 @@ floating_pos_set_hidebuttons (BasePWidget *basep)
 	}
 }
 
-static PanelOrientType
+static PanelOrient
 floating_pos_get_applet_orient (BasePWidget *basep)
 {
 	PanelWidget *panel = PANEL_WIDGET (basep->panel);
 	if (panel->orient == PANEL_HORIZONTAL)
-		return (FLOATING_POS (basep->pos)->y < 
-			gdk_screen_height () / 2)
-			? ORIENT_DOWN : ORIENT_UP;
+		return (FLOATING_POS (basep->pos)->y -
+			multiscreen_y (basep->screen) < 
+			multiscreen_height (basep->screen) / 2)
+			? PANEL_ORIENT_DOWN : PANEL_ORIENT_UP;
 	else
-		return (FLOATING_POS (basep->pos)->x < 
-			gdk_screen_width () /2)
-			? ORIENT_RIGHT : ORIENT_LEFT;
+		return (FLOATING_POS (basep->pos)->x -
+		       	multiscreen_x (basep->screen) < 
+			multiscreen_width (basep->screen) /2)
+			? PANEL_ORIENT_RIGHT : PANEL_ORIENT_LEFT;
 }
 
-static PanelOrientType
+static PanelOrient
 floating_pos_get_hide_orient (BasePWidget *basep)
 {
 	FloatingPos *pos = FLOATING_POS (basep->pos);
@@ -165,19 +166,23 @@ floating_pos_get_hide_orient (BasePWidget *basep)
 	switch (basep->state) {
 	case BASEP_HIDDEN_LEFT:
 		return (panel->orient == PANEL_HORIZONTAL)
-			? ORIENT_LEFT : ORIENT_UP;
+			? PANEL_ORIENT_LEFT : PANEL_ORIENT_UP;
 	case BASEP_HIDDEN_RIGHT:
 		return (panel->orient == PANEL_HORIZONTAL)
-			? ORIENT_RIGHT : ORIENT_DOWN;
+			? PANEL_ORIENT_RIGHT : PANEL_ORIENT_DOWN;
 	case BASEP_AUTO_HIDDEN:
 		if (panel->orient == PANEL_HORIZONTAL) {
-			return ((pos->x > (gdk_screen_width () - pos->x -
-					   basep->shown_alloc.width))
-				? ORIENT_RIGHT : ORIENT_LEFT);
+			return ((pos->x >
+				 (multiscreen_width (basep->screen) +
+				  multiscreen_x (basep->screen) - pos->x -
+				  basep->shown_alloc.width))
+				? PANEL_ORIENT_RIGHT : PANEL_ORIENT_LEFT);
 		} else {
-			return ((pos->y > (gdk_screen_height () - pos->y -
-					   basep->shown_alloc.height))
-				? ORIENT_DOWN : ORIENT_UP);
+			return ((pos->y >
+				 (multiscreen_height (basep->screen) +
+				  multiscreen_y (basep->screen) - pos->y -
+				  basep->shown_alloc.height))
+				? PANEL_ORIENT_DOWN : PANEL_ORIENT_UP);
 		}
 	default:
 		g_warning ("not hidden");
@@ -193,33 +198,49 @@ floating_pos_get_menu_pos (BasePWidget *basep,
 			   int wx, int wy,
 			   int ww, int wh)
 {	
-	PanelOrientType menu_orient = floating_pos_get_applet_orient (basep);
+	PanelOrient menu_orient = floating_pos_get_applet_orient (basep);
 	
 	switch (menu_orient) {
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_DOWN:
 		*x += wx;
 		*y = wy + wh;
 		break;
-	case ORIENT_LEFT:
+	case PANEL_ORIENT_LEFT:
 		*x = wx - mreq->width;
 		*y += wy;
 		break;
 	default:
-	case ORIENT_UP:
+	case PANEL_ORIENT_UP:
 		*x += wx;
 		*y = wy - mreq->height;
 		break;
-	case ORIENT_RIGHT:
+	case PANEL_ORIENT_RIGHT:
 		*x = wx + ww;
 		*y += wy;
 		break;
 	}
 }
 
+static int
+xclamp (int screen, int x, int w)
+{
+	return CLAMP (x, 0,
+		      multiscreen_width (screen) - w);
+}
+
+static int
+yclamp (int screen, int y, int h)
+{
+	return CLAMP (y, 0, 
+		      multiscreen_height (screen) - h -
+		      foobar_widget_get_height (screen));
+}
+
 static void
 floating_pos_set_pos (BasePWidget *basep,
 		      int x, int y,
-		      int w, int h)
+		      int w, int h,
+		      gboolean force)
 {
 	FloatingPos *pos = FLOATING_POS(basep->pos);
 	gint16 newx, newy;
@@ -227,8 +248,8 @@ floating_pos_set_pos (BasePWidget *basep,
 	x -= basep->offset_x;
 	y -= basep->offset_y;
 
-	newx = pos->x;
-	newy = pos->y;
+	x -= multiscreen_x (basep->screen);
+	y -= multiscreen_y (basep->screen);
 
 	if (PANEL_WIDGET (basep->panel)->orient == PANEL_HORIZONTAL) {
 		switch (basep->state) {
@@ -245,7 +266,7 @@ floating_pos_set_pos (BasePWidget *basep,
 		}
 	}
 
-	newx = CLAMP (x, 0, gdk_screen_width () - w);
+	newx = xclamp (basep->screen, x, w);
 
 	if (PANEL_WIDGET (basep->panel)->orient == PANEL_VERTICAL) {
 		switch (basep->state) {
@@ -261,14 +282,14 @@ floating_pos_set_pos (BasePWidget *basep,
 			break;
 		}
 	}
-	newy = CLAMP (y, 0, gdk_screen_height () - h);
+	newy = yclamp (basep->screen, y, h);
 
 	if (newy != pos->y || newx != pos->x) {
 		pos->x = newx;
 		pos->y = newy;
-		gtk_signal_emit (GTK_OBJECT (pos),
-				 floating_pos_signals[COORDS_CHANGE_SIGNAL],
-				 pos->x, pos->y);
+		g_signal_emit (G_OBJECT (pos),
+			       floating_pos_signals[COORDS_CHANGE_SIGNAL],
+			       0, pos->x, pos->y);
 		gtk_widget_queue_resize (GTK_WIDGET (basep));
 	}
 }
@@ -278,41 +299,41 @@ floating_pos_get_pos(BasePWidget *basep,
 		     int *x, int *y,
 		     int w, int h)
 {
-	*x = CLAMP (FLOATING_POS (basep->pos)->x, 0, gdk_screen_width () - w);
-	*y = CLAMP (FLOATING_POS (basep->pos)->y,
-		    foobar_widget_get_height (basep->screen),
-		    gdk_screen_height () - h);
+	*x = xclamp (basep->screen, FLOATING_POS (basep->pos)->x, w);
+	*y = yclamp (basep->screen, FLOATING_POS (basep->pos)->y, h);
+	*x += multiscreen_x (basep->screen);
+	*y += multiscreen_y (basep->screen);
 }
 
 static void
 floating_pos_get_hide_size (BasePWidget *basep, 
-			    PanelOrientType hide_orient,
+			    PanelOrient hide_orient,
 			    int *w, int *h)
 {
 	if (basep->state == BASEP_AUTO_HIDDEN &&
 	    ! basep->hidebuttons_enabled) {
 		switch (hide_orient) {
-		case ORIENT_UP:
-		case ORIENT_DOWN:
-			*h = pw_minimized_size;
+		case PANEL_ORIENT_UP:
+		case PANEL_ORIENT_DOWN:
+			*h = panel_gconf_global_config_get_int ("panel-minimized-size");
 			break;
-		case ORIENT_LEFT:
-		case ORIENT_RIGHT:
-			*w = pw_minimized_size;
+		case PANEL_ORIENT_LEFT:
+		case PANEL_ORIENT_RIGHT:
+			*w = panel_gconf_global_config_get_int ("panel-minimized-size");
 			break;
 		}
 	} else {
 		switch (hide_orient) {
-		case ORIENT_UP:
+		case PANEL_ORIENT_UP:
 			*h = get_requisition_height (basep->hidebutton_n);
 			break;
-		case ORIENT_RIGHT:
+		case PANEL_ORIENT_RIGHT:
 			*w = get_requisition_width (basep->hidebutton_w);
 			break;
-		case ORIENT_DOWN:
+		case PANEL_ORIENT_DOWN:
 			*h = get_requisition_height (basep->hidebutton_s);
 			break;
-		case ORIENT_LEFT:
+		case PANEL_ORIENT_LEFT:
 			*w = get_requisition_width (basep->hidebutton_e);
 			break;
 		}
@@ -325,24 +346,24 @@ floating_pos_get_hide_size (BasePWidget *basep,
 
 static void
 floating_pos_get_hide_pos (BasePWidget *basep,
-			   PanelOrientType hide_orient,
+			   PanelOrient hide_orient,
 			   int *x, int *y,
 			   int w, int h)
 {
 	switch (hide_orient) {
-	case ORIENT_UP:
-	case ORIENT_LEFT:
+	case PANEL_ORIENT_UP:
+	case PANEL_ORIENT_LEFT:
 		break;
-	case ORIENT_RIGHT:
+	case PANEL_ORIENT_RIGHT:
 		*x += w - ((basep->state == BASEP_AUTO_HIDDEN &&
 			    ! basep->hidebuttons_enabled)
-			   ? pw_minimized_size
+			   ? panel_gconf_global_config_get_int ("panel-minimized-size")
 			   : get_requisition_width (basep->hidebutton_w));
 		break;
-	case ORIENT_DOWN:
+	case PANEL_ORIENT_DOWN:
 		*y += h - ((basep->state == BASEP_AUTO_HIDDEN &&
 			    ! basep->hidebuttons_enabled)
-			   ? pw_minimized_size
+			   ? panel_gconf_global_config_get_int ("panel-minimized-size")
 			   : get_requisition_height (basep->hidebutton_s));
 		break;
 	}
@@ -387,7 +408,9 @@ floating_pos_pre_convert_hook (BasePWidget *basep)
 
 void 
 floating_widget_change_params (FloatingWidget *floating,
-			       gint16 x, gint16 y,
+			       int screen,
+			       gint16 x,
+			       gint16 y,
 			       PanelOrientation orient,
 			       BasePMode mode,
 			       BasePState state,
@@ -403,31 +426,37 @@ floating_widget_change_params (FloatingWidget *floating,
 			       gboolean rotate_pixmap_bg,
 			       GdkColor *back_color)
 {
-	FloatingPos *pos = FLOATING_POS (BASEP_WIDGET (floating)->pos);
+	BasePWidget *basep = BASEP_WIDGET (floating);
+	FloatingPos *pos = FLOATING_POS (basep->pos);
 
-	if (PANEL_WIDGET (BASEP_WIDGET (floating)->panel)->orient != orient)
+	if (PANEL_WIDGET (basep->panel)->orient != orient)
 		BASEP_WIDGET (floating)->request_cube = TRUE;
 
-	x = CLAMP (x, 0, gdk_screen_width () - 
-		   BASEP_WIDGET (floating)->shown_alloc.width);
-	y = CLAMP (y, 0, gdk_screen_height () - 
-		   BASEP_WIDGET (floating)->shown_alloc.height);
+	x = xclamp (basep->screen, x, basep->shown_alloc.width);
+	y = yclamp (basep->screen, y, basep->shown_alloc.height);
 
 	if (y != pos->y || x != pos->x) {
 		pos->x = x;
 		pos->y = y;
-		gtk_signal_emit (GTK_OBJECT (pos),
-				 floating_pos_signals[COORDS_CHANGE_SIGNAL],
-				 x, y);
+		g_signal_emit (G_OBJECT (pos),
+			       floating_pos_signals[COORDS_CHANGE_SIGNAL],
+			       0, x, y);
 	}
 
-	basep_widget_change_params (BASEP_WIDGET (floating),
-				    orient, sz, mode, state,
-				    level, avoid_on_maximize,
+	basep_widget_change_params (basep,
+				    screen,
+				    orient,
+				    sz,
+				    mode,
+				    state,
+				    level,
+				    avoid_on_maximize,
 				    hidebuttons_enabled,
 				    hidebutton_pixmap_enabled,
-				    back_type, back_pixmap,
-				    fit_pixmap_bg, strech_pixmap_bg,
+				    back_type,
+				    back_pixmap,
+				    fit_pixmap_bg,
+				    strech_pixmap_bg,
 				    rotate_pixmap_bg,
 				    back_color);
 				    
@@ -435,14 +464,16 @@ floating_widget_change_params (FloatingWidget *floating,
 
 void
 floating_widget_change_orient (FloatingWidget *floating,
-			     PanelOrientation orient)
+			       PanelOrientation orient)
 {
 	FloatingPos *pos = FLOATING_POS (floating->pos);
 	if (PANEL_WIDGET (BASEP_WIDGET (floating)->panel)->orient != orient) {
 		BasePWidget *basep = BASEP_WIDGET (floating);
 		PanelWidget *panel = PANEL_WIDGET (basep->panel);
 		floating_widget_change_params (floating, 
-					       pos->x, pos->y,
+					       basep->screen,
+					       pos->x,
+					       pos->y,
 					       orient,
 					       basep->mode,
 					       basep->state,
@@ -469,7 +500,9 @@ floating_widget_change_coords (FloatingWidget *floating,
 		BasePWidget *basep = BASEP_WIDGET (floating);
 		PanelWidget *panel = PANEL_WIDGET (basep->panel);
 		floating_widget_change_params (floating, 
-					       x, y,
+					       basep->screen,
+					       x,
+					       y,
 					       panel->orient,
 					       basep->mode,
 					       basep->state,
@@ -488,7 +521,9 @@ floating_widget_change_coords (FloatingWidget *floating,
 }
 
 GtkWidget *
-floating_widget_new (gint16 x, gint16 y,
+floating_widget_new (int screen,
+		     gint16 x,
+		     gint16 y,
 		     PanelOrientation orient,
 		     BasePMode mode,
 		     BasePState state,
@@ -507,8 +542,8 @@ floating_widget_new (gint16 x, gint16 y,
 	FloatingWidget *floating;
 	FloatingPos *pos;
 
-	floating = gtk_type_new (TYPE_FLOATING_WIDGET);
-	floating->pos = gtk_type_new (TYPE_FLOATING_POS);
+	floating = gtk_type_new (FLOATING_TYPE_WIDGET);
+	floating->pos = gtk_type_new (FLOATING_TYPE_POS);
 	pos = FLOATING_POS (floating->pos);
 
 	pos->x = x;
@@ -516,8 +551,11 @@ floating_widget_new (gint16 x, gint16 y,
 
 	basep_widget_construct (BASEP_WIDGET (floating),
 				TRUE, FALSE,
+				screen,
 				orient,
-				sz, mode, state,
+				sz,
+				mode,
+				state,
 				level,
 				avoid_on_maximize,
 				hidebuttons_enabled,
