@@ -10,14 +10,13 @@
 #include "sliding-widget.h"
 #include "panel_config_global.h"
 #include "foobar-widget.h"
+#include "panel-marshal.h"
 #include "panel-util.h"
 #include "multiscreen-stuff.h"
-
-extern GlobalConfig global_config;
-extern int pw_minimized_size;
+#include "panel-typebuiltins.h"
 
 static void sliding_pos_class_init (SlidingPosClass *klass);
-static void sliding_pos_init (SlidingPos *pos);
+static void sliding_pos_instance_init (SlidingPos *pos);
 
 static void sliding_pos_set_pos (BasePWidget *basep,
 				 int x, int y,
@@ -27,30 +26,31 @@ static void sliding_pos_get_pos (BasePWidget *basep,
 				 int *x, int *y,
 				 int w, int h);
 
-static BorderPosClass *parent_class;
+static BorderPosClass *sliding_pos_parent_class;
 
-GtkType
+GType
 sliding_pos_get_type (void)
 {
-	static GtkType sliding_pos_type = 0;
+	static GType object_type = 0;
 
-	if (sliding_pos_type == 0) {
-		GtkTypeInfo sliding_pos_info = {
-			"SlidingPos",
-			sizeof (SlidingPos),
-			sizeof (SlidingPosClass),
-			(GtkClassInitFunc) sliding_pos_class_init,
-			(GtkObjectInitFunc) sliding_pos_init,
-			NULL,
-			NULL,
-			NULL
+	if (object_type == 0) {
+		static const GTypeInfo object_info = {
+                    sizeof (SlidingPosClass),
+                    (GBaseInitFunc)         NULL,
+                    (GBaseFinalizeFunc)     NULL,
+                    (GClassInitFunc)        sliding_pos_class_init,
+                    NULL,                   /* class_finalize */
+                    NULL,                   /* class_data */
+                    sizeof (SlidingPos),
+                    0,                      /* n_preallocs */
+                    (GInstanceInitFunc)     sliding_pos_instance_init 
 		};
 
-		sliding_pos_type = gtk_type_unique (TYPE_BORDER_POS,
-						    &sliding_pos_info);
+		object_type = g_type_register_static (BORDER_TYPE_POS, "SlidingPos", &object_info, 0);
+		sliding_pos_parent_class = g_type_class_ref (BORDER_TYPE_POS);
 	}
 			       
-	return sliding_pos_type;
+	return object_type;
 }
 
 enum {
@@ -65,40 +65,38 @@ static void
 sliding_pos_class_init (SlidingPosClass *klass)
 {
 	BasePPosClass *pos_class = BASEP_POS_CLASS(klass);
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);
-	parent_class = gtk_type_class(TYPE_BORDER_POS);
+	GObjectClass *object_class = G_OBJECT_CLASS(klass);
 
 	sliding_pos_signals[ANCHOR_CHANGE_SIGNAL] =
-		gtk_signal_new("anchor_change",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(SlidingPosClass,
-						 anchor_change),
-			       gtk_marshal_NONE__ENUM,
-			       GTK_TYPE_NONE,
-			       1, GTK_TYPE_ENUM);
+                g_signal_new ("anchor_change",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (SlidingPosClass, anchor_change),
+                              NULL,
+                              NULL, 
+                              panel_marshal_VOID__ENUM,
+                              G_TYPE_NONE,
+                              1,
+                              PANEL_TYPE_SLIDING_ANCHOR);
 
 	sliding_pos_signals[OFFSET_CHANGE_SIGNAL] =
-		gtk_signal_new("offset_change",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET(SlidingPosClass,
-						 offset_change),
-			       gtk_marshal_NONE__INT,
-			       GTK_TYPE_NONE,
-			       2, GTK_TYPE_INT,
-			       GTK_TYPE_INT);
+                g_signal_new ("offset_change",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (SlidingPosClass, offset_change),
+                              NULL,
+                              NULL, 
+                              panel_marshal_VOID__ENUM,
+                              G_TYPE_NONE,
+                              2,
+                              G_TYPE_INT, G_TYPE_INT); 
 
-	gtk_object_class_add_signals (object_class,
-				      sliding_pos_signals,
-				      LAST_SIGNAL);
-	
 	pos_class->set_pos = sliding_pos_set_pos;
 	pos_class->get_pos = sliding_pos_get_pos;
 }
 
 static void
-sliding_pos_init (SlidingPos *pos) { }
+sliding_pos_instance_init (SlidingPos *pos) { }
 
 static void
 sliding_pos_set_pos (BasePWidget *basep,
@@ -298,8 +296,8 @@ sliding_widget_new (int screen,
 		    gboolean rotate_pixmap_bg,
 		    GdkColor *back_color)
 {
-	SlidingWidget *sliding = gtk_type_new (TYPE_SLIDING_WIDGET);
-	SlidingPos *pos = gtk_type_new (TYPE_SLIDING_POS);
+	SlidingWidget *sliding = gtk_type_new (SLIDING_TYPE_WIDGET);
+	SlidingPos *pos = gtk_type_new (SLIDING_TYPE_POS);
 
 	pos->anchor = anchor;
 	pos->offset = offset;
@@ -351,17 +349,17 @@ sliding_widget_change_params (SlidingWidget *sliding,
 
 	if (anchor != pos->anchor) {
 		pos->anchor = anchor;
-		gtk_signal_emit (GTK_OBJECT (pos),
-				 sliding_pos_signals[ANCHOR_CHANGE_SIGNAL],
-				 anchor);
+		g_signal_emit (G_OBJECT (pos),
+			       sliding_pos_signals[ANCHOR_CHANGE_SIGNAL],
+			       0, anchor);
 		
 	}
 
 	if (offset != pos->offset) {
 		pos->offset = offset;
-		gtk_signal_emit (GTK_OBJECT (pos),
-				 sliding_pos_signals[OFFSET_CHANGE_SIGNAL],
-				 offset);
+		g_signal_emit (G_OBJECT (pos),
+			       sliding_pos_signals[OFFSET_CHANGE_SIGNAL],
+			       0, offset);
 	}
 
 	border_widget_change_params (BORDER_WIDGET (sliding),
