@@ -1,9 +1,9 @@
 #ifndef SWALLOW_H
 #define SWALLOW_H
 
-#include <panel-widget.h>
+#include "panel-widget.h"
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 typedef enum {
 	SWALLOW_VERTICAL,
@@ -25,13 +25,13 @@ typedef struct {
 	gboolean clean_remove;
 } Swallow;
 
-void load_swallow_applet(char *path, char *params, int width, int height,
+void load_swallow_applet(const char *path, const char *params, int width, int height,
 			 PanelWidget *panela, int pos, gboolean exactpos);
 void set_swallow_applet_orient(Swallow *swallow, SwallowOrient orient);
 
 /*I couldn't resist the naming of this function*/
 void ask_about_swallowing(PanelWidget *panel, int pos, gboolean exactpos);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
